<?php // $Id: news.form.inc,v 1.7 2009/08/26 17:48:04 vauxia Exp $

/**
 * @file
 *
 * Form functions for the News module.
 */

/**
 * The form page for user-initiated Newsletter activities.
 */
function news_form($form_state, $nids = array()) {
  if (!$send = $form_state['send']) {
    $send = (object) send_profile_load('news');
    $send->nids = ($nids && !is_array($nids)) ? explode(' ', $nids) : $nids;
    $send->from_element = 'news_contact';
    $send->to_element = 'news_mlm';
    $send->message_element = $nids ? 'send_message_compose': 'send_message_edit';
    $send->action = request_uri();
  }

  if (isset($form_state['clicked_button'])) {
    if ($form_state['clicked_button']['#value'] == t('Edit')) {
      $send->message_element = 'send_message_edit';
    }
    elseif ($form_state['clicked_button']['#value'] == t('Compose')) {
      $send->message_element = 'send_message_compose';
    }
  }

  $form = array(
    '#send_element' => 'send',
  );

  // Ensure that the *original* form action is used, not an AHAH-rewritten one.
  $form['#action'] = $send->action;

  $form['send'] = array(
    '#type' => 'send',
    '#send' => $send,
  );

  $form['extra']['compose'] = array(
    '#type' => 'submit',
    '#value' => t('Compose'),
    '#submit' => array('send_submit_refresh'),
  );

  $form['extra']['edit'] = array(
    '#type' => 'submit',
    '#value' => t('Edit'),
    '#submit' => array('send_submit_refresh'),
  );

  $form['buttons']['test'] = array(
    '#type' => 'submit',
    '#value' => t('Send test message'),
    '#submit' => array('news_form_test_delivery'),
  );
  $form['buttons']['submit'] = array(
    '#type' => 'submit', '#value' => t('Send'),
  );

  return $form;
}

/**
 * A #process handler for the news_mlm form element.
 */
function news_mlm_element_process($element, $edit, &$form_state, $form) {
  foreach (mlm_lists('Announcement') as $list => $mlm) {
    $options[$list] = $mlm->title;
  }
  $name = $element['#name'];
  if (isset($form_state['send']->{$name}['lists'])) {
    $selected = $form_state['send']->{$name}['lists'];
  }
  elseif (isset($element['#value']['lists'])) {
    $selected = $element['#value']['lists'];
  }
  else {
    $selected = array();
  }
  $element['lists'] = array(
    '#type'          => 'checkboxes',
    '#title'         => t('Mailing lists'),
    '#options'       => $options,
    '#default_value' => $selected,
    '#required'      => $element['#required'],
  );
  return $element;
}

/**
 * An #after_build handler for a the news_mlm element.
 * Set the element value in a format that will be recognized by send_contact.
 */
function news_mlm_element_set_value($element, &$form_state) {
  $lists = array();
  if ($element['#value']) {
    foreach ($element['#value']['lists'] as $lid => $status) {
      if ($status) $lists[] = array('lid' => $lid);
    }
  }
  $element['#value'] = $lists;
  return $element;
}

/**
 * A #process handler for the news_contact form element.
 */
function news_contact_element_process($element, $edit, &$form_state, $form) {
  $element['name'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Name'),
    '#default_value' => variable_get('site_name', 'Drupal'),
  );
  $element['mail'] = array(
    '#type'          => 'textfield',
    '#title'         => t('E-mail'),
    '#default_value' => variable_get('site_mail', ''),
  );
  return $element;
}

/**
 * A submit handler for the news form that delivers a test message to the admin.
 */
function news_form_test_delivery($form, &$form_state) {
  global $user;
  send_submit_refresh($form, $form_state);

  $send = $form_state['send'];
  mimemail($send->from, $user, $send->message['subject'], $send->message['body']);
  drupal_set_message(t('Test message sent to !mail', array('!mail' => $user->mail)));
}
